==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/nativemethods/JavaNetInetAddressNative.h <==
// public class soot.jimple.toolkits.pointer.nativemethods.JavaNetInetAddressNative

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d8fc53f3b36ba99 soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative
// @dep_class adf075d6a4c28634 soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

#include "soot/jimple/toolkits/pointer/nativemethods/NativeMethodClass.h"

#ifndef _JC_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative_H_
#define _JC_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$object;
struct _jc_soot_jimple_toolkits_pointer_representations_ReferenceVariable$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$sub_refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$object	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vmethods	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vtable	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vtype	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$method$simulateMethod$16021ad0ff992382(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$method_info$simulateMethod$16021ad0ff992382;

// Static methods
extern struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$object *_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$method$v$f48fdfd3008c4c62(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vmethods {
	void	(*simulateMethod$16021ad0ff992382)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vmethods	soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$refs {
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$sub_refs	soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$object {
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vtype _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/nativemethods/JavaNetInetAddressNative.h <==
// public class soot.jimple.toolkits.pointer.nativemethods.JavaNetInetAddressNative

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d8fc53f3b36ba99 soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative
// @dep_class adf075d6a4c28634 soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

// header file dependencies
// @dep_header soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass

#include "soot/jimple/toolkits/pointer/nativemethods/NativeMethodClass.h"

#ifndef _JC_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative_H_
#define _JC_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_SootMethod$object;
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$object;
struct _jc_soot_jimple_toolkits_pointer_representations_ReferenceVariable$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$sub_refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$refs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$object	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vmethods	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vtable	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vtype	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$method$simulateMethod$16021ad0ff992382(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$method_info$simulateMethod$16021ad0ff992382;

// Static methods
extern struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$object *_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$method$v$f48fdfd3008c4c62(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vmethods {
	void	(*simulateMethod$16021ad0ff992382)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$vmethods	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vmethods	soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$refs {
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$sub_refs	soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_refs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodClass;
    _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$object {
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$vtype _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_nativemethods_JavaNetInetAddressNative_H_ */
